@@ -4,7 +4,7 @@ s1 <- USArrests         #  Violent Crime Rates by US State  (4 variables)
 s2 <- attitude          #The Chatterjee-Price Attitude Data
 s3 <- Harman23.cor$cov     #   Harman Example 2.3 8 physical measurements
 s4 <- Harman74.cor$cov     #   Harman Example 7.4  24 mental measurements
-s5 <- ability.cov$cov       #  8 Ability and Intelligence Tests 
+s5 <- ability.cov$cov       #  6 Ability and Intelligence Tests 
 
 #convert covariance to correlation
 d5 <- diag(1/sqrt(diag(s5)))
@@ -21,20 +21,20 @@ for (i in first:last) {
 			fa2 <- factor.pa(test.data,2)
 			fp <-    fa.parallel(test.data)
 			vss2 <- VSS(test.data)
-			vsspc <- VSS(test.data)
+			vsspc <- VSS(test.data,pc="pc")
 		} else {
 			fa2 <- factor.pa(test.data,2,n.obs=200)
 			cluster.plot(fa2)
 			fp <-    fa.parallel(test.data,n.obs=200)
 			vss2 <- VSS(test.data,n.obs=200)
-			vsspc <- VSS(test.data,n.obs=200)
-			VSS.plot(vss2)
+			vsspc <- VSS(test.data,pc="pc",n.obs=200)
+			
 
 			}
 
 
-	ic <-   ICLUST(test.data)
-	if(require(GPArotation)) {om <-  omega(test.data)} else {warning("Omega requires the GPArotation package to be loaded")
+	ic <-   ICLUST(test.data,plot=FALSE)
+	if(require(GPArotation)) {om <-  omega(test.data,plot=FALSE)} else {warning("Omega requires the GPArotation package to be loaded")
 	  om <- NULL}
 	fc <- factor.congruence(pc2,fa2)
 	
@@ -54,20 +54,23 @@ for (i in first:last) {
   simple.par <- fa.parallel(simple)
   fa.simple <- factor.pa(simple,2)
   fa.simple.keys <- ICLUST.sort(fa.simple,keys=TRUE)
-  simple.scores <-  score.items(fa.simple.keys$clusters,simple)
+ 
+ simple.scores <-  score.items(fa.simple.keys$clusters,simple)
   pairs.panels(simple.scores$scores)
-  f4 <- VSS.simulate()
- if (!require(polycor)) { warning("psycho.demo requires the polycor package")
-         psych.d <- NULL  } else  {psych.d <- phi.demo() } 
-       
+   f4 <- VSS.simulate()
+    psych.d <- NULL 
+   #the next test, phi.demo, throws multiple warnings that are from the polycor package and can not be found
+  #if (!require(polycor)) { warning("psycho.demo requires the polycor package")  psych.d <- NULL  } else  {psych.d <- phi.demo() } 
   cong <- congeneric.sim()
-  cluster.plot(factor.pa(circ.sim(nvar=24),nf=2),title="two circumplex factors")
-  pairs.panels(cong)
+  
+
+   
+   cluster.plot(factor.pa(circ.sim(nvar=24),nf=2),title="two circumplex factors")
+ pairs.panels(cong) 
+
  if(require(Rgraphviz)) { fa.graph(factor.pa(item.sim(16),2) ,title="Principal factor of a simple structure") 
-  	ic.out <- ICLUST(s4)
-   	ICLUST.rgraph(ic.out,title="ICLUST of 24 Mental abilities")  
-  	jen <-  omega(make.hierarchical())
-  	omega.graph(jen,title="Omega with Schmid Leihman")
+  	ic.out <- ICLUST(s4,title="ICLUST of 24 Mental abilities")
+  	jen <-  omega(make.hierarchical(),title="Omega with Schmid Leihman")
   	omega.graph(jen,sl=FALSE,title="Omega with hierarchical factors")
  } else {warning("fa.graph, omega.graph, ICLUST.rgraph require Rgraphviz") }
   
